summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/rmd_get_frame.c4
-rw-r--r--src/rmd_get_frame.h4
-rw-r--r--src/rmd_threads.c2
3 files changed, 5 insertions, 5 deletions
diff --git a/src/rmd_get_frame.c b/src/rmd_get_frame.c
index cd49258..6f82b4a 100644
--- a/src/rmd_get_frame.c
+++ b/src/rmd_get_frame.c
@@ -399,7 +399,7 @@ static boolean paused(ProgData *pdata)
* and image_buffer_ready is signaled for the cache/encode side to consume the
* yuv buffer.
*/
-void *rmdGetFrame(ProgData *pdata)
+void *rmdGetFrames(ProgData *pdata)
{
int blocks_w = pdata->enc_data->yuv.y_width / Y_UNIT_WIDTH,
blocks_h = pdata->enc_data->yuv.y_height / Y_UNIT_WIDTH;
@@ -413,7 +413,7 @@ void *rmdGetFrame(ProgData *pdata)
int init_img1 = 0, init_img2 = 0, img_sel, d_buff;
unsigned frameno = 0;
- rmdThreadsSetName("rmdGetFrame");
+ rmdThreadsSetName("rmdGetFrames");
img_sel = d_buff = pdata->args.full_shots;
diff --git a/src/rmd_threads.c b/src/rmd_threads.c
index 8514649..db27716 100644
--- a/src/rmd_threads.c
+++ b/src/rmd_threads.c
@@ -64,7 +64,7 @@ void rmdThreads(ProgData *pdata)
/*start threads*/
pthread_create( &image_capture_t,
NULL,
- (void *)rmdGetFrame,
+ (void *)rmdGetFrames,
(void *)pdata);
if (pdata->args.encOnTheFly)
© All Rights Reserved
diff --git a/src/rmd_get_frame.h b/src/rmd_get_frame.h
index 162c05e..976c8fd 100644
--- a/src/rmd_get_frame.h
+++ b/src/rmd_get_frame.h
@@ -31,11 +31,11 @@
/**
* Retrieve frame form xserver, and transform to a yuv buffer,
* either directly(full shots) or by calling UpdateImage.
* \param pdata ProgData struct containing all program data
*/
-void *rmdGetFrame(ProgData *pdata);
+void *rmdGetFrames(ProgData *pdata);
#endif
@@ -31,11 +31,11 @@
/**
-* Retrieve frame form xserver, and transform to a yuv buffer,
+* Retrieve frames from xserver, and transform to a yuv buffer,
* either directly(full shots) or by calling UpdateImage.
* \param pdata ProgData struct containing all program data